==> haskell-pipes-http-1.0.5-160-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-HyrP6pWOsh9JzNeERrGXwZ
key: pipes-http-1.0.5-HyrP6pWOsh9JzNeERrGXwZ
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
abi: 94a3dd86020b14adc9eb7ef65824fb26
exposed: True
exposed-modules:
    Pipes.HTTP
import-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-HyrP6pWOsh9JzNeERrGXwZ
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    pipes-4.3.9-HljQuAs1RYPKwbvMGf3aZv
    http-client-0.5.13.1-6ErjtB8irYdEm2hFyrXCBl
    http-client-tls-0.3.5.3-4IrdPC2gJtIH3Wjs6gqHU0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             pipes-4.3.9-HljQuAs1RYPKwbvMGf3aZv=c33f18ef33e633c9bb9691157c3e6964
             http-client-0.5.13.1-6ErjtB8irYdEm2hFyrXCBl=1b01da4e47343111f14a209fa010447a
             http-client-tls-0.3.5.3-4IrdPC2gJtIH3Wjs6gqHU0=49f2c7e970a74333f727c917174c6bc8
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.5-161-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes-http
version: 1.0.5
id: pipes-http-1.0.5-1iig8dAVteWHrRh9qk9KFL
key: pipes-http-1.0.5-1iig8dAVteWHrRh9qk9KFL
license: BSD-3-Clause
copyright: 2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library
category: Pipes, Web
abi: ac298432026043f39bb502027588a80f
exposed: True
exposed-modules:
    Pipes.HTTP
import-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-http-1.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/pipes-http-1.0.5
hs-libraries: HSpipes-http-1.0.5-1iig8dAVteWHrRh9qk9KFL
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    pipes-4.3.9-HljQuAs1RYPKwbvMGf3aZv
    http-client-0.5.13.1-Ix7fmogA1Hj11uABzfxUxL
    http-client-tls-0.3.5.3-6XXmycQeLrC1fP2aS1Msko
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             pipes-4.3.9-HljQuAs1RYPKwbvMGf3aZv=c33f18ef33e633c9bb9691157c3e6964
             http-client-0.5.13.1-Ix7fmogA1Hj11uABzfxUxL=b5bbbb2416b8c71b835e8b7e040cae41
             http-client-tls-0.3.5.3-6XXmycQeLrC1fP2aS1Msko=2358351eea6016335b2e106bccc9f333
haddock-interfaces: /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html: /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
